API

Struct API 

pub struct API { /* private fields */ }
A wrapper for the VapourSynth API.

Implementations

Source

impl API

pub fn get() -> Option<Self>

Retrieves the VapourSynth API.

Returns None on error, for example if the requested API version (selected with features, see the crate-level docs) is not supported.

pub fn log( self, message_type: MessageType, message: &str, ) -> Result<(), NulError>

Sends a message through VapourSynth’s logging framework.

pub fn create_core<'core>(self, threads: i32) -> CoreRef<'core>

Creates and returns a new core.

Note that there’s currently no safe way of freeing the returned core, and the lifetime is unbounded, because it can live for an arbitrary long time. You may use the (unsafe) vapoursynth_sys::VSAPI::freeCore() after ensuring that all frame requests have completed and all objects belonging to the core have been released.